match_filter.Template
=====================

See notes and warnings on correlations here: correlation_warnings_

.. _correlation_warnings: utils.correlate.html#notes-on-accuracy

.. currentmodule:: eqcorrscan.core.match_filter

.. autoclass:: Template

   .. rubric:: Methods

   .. autosummary::

      construct
      copy
      detect
      read
      same_processing
      write

   .. automethod:: __init__
   .. automethod:: construct
   .. automethod:: copy
   .. automethod:: detect
   .. automethod:: read
   .. automethod:: same_processing
   .. automethod:: write
